#ifndef SYSTEMPROFILES_H
#define SYSTEMPROFILES_H

#include <QObject>
#include <QStringList>
#include <QDebug>
#ifdef Q_WS_MAEMO_5
    #include "profiled/libprofile.h"
#endif

class SystemProfiles : public QObject
{
    Q_OBJECT
public:
    explicit SystemProfiles(QObject *parent = 0);
    static QStringList profilesList();
    static QString currentProfile();
    static void setProfile(QString profileName);

private:
    static void profileChanged_cb(const char *profile, void *user_data);

signals:
    void profileChanged(QString profileName);

public slots:

};

#endif // SYSTEMPROFILES_H
